@@ -1,4 +1,5 @@
 import contextlib
+import os
 import re
 import sys
 
@@ -11,6 +12,7 @@ from sentry_sdk.utils import (
     to_string,
     is_sentry_url,
     _is_external_source,
+    _module_in_list,
 )
 from sentry_sdk._compat import PY2, iteritems
 from sentry_sdk._types import TYPE_CHECKING
@@ -190,29 +192,44 @@ def add_query_source(hub, span):
         return
 
     project_root = client.options["project_root"]
+    in_app_include = client.options.get("in_app_include")
+    in_app_exclude = client.options.get("in_app_exclude")
 
     # Find the correct frame
     frame = sys._getframe()  # type: Union[FrameType, None]
     while frame is not None:
         try:
             abs_path = frame.f_code.co_filename
+            if abs_path and PY2:
+                abs_path = os.path.abspath(abs_path)
         except Exception:
             abs_path = ""
 
         try:
-            namespace = frame.f_globals.get("__name__")
+            namespace = frame.f_globals.get("__name__")  # type: Optional[str]
         except Exception:
             namespace = None
 
         is_sentry_sdk_frame = namespace is not None and namespace.startswith(
             "sentry_sdk."
         )
+
+        should_be_included = not _is_external_source(abs_path)
+        if namespace is not None:
+            if in_app_exclude and _module_in_list(namespace, in_app_exclude):
+                should_be_included = False
+            if in_app_include and _module_in_list(namespace, in_app_include):
+                # in_app_include takes precedence over in_app_exclude, so doing it
+                # at the end
+                should_be_included = True
+
         if (
             abs_path.startswith(project_root)
-            and not _is_external_source(abs_path)
+            and should_be_included
             and not is_sentry_sdk_frame
         ):
             break
+
         frame = frame.f_back
     else:
         frame = None
@@ -250,15 +267,6 @@ def add_query_source(hub, span):
             span.set_data(SPANDATA.CODE_FUNCTION, frame.f_code.co_name)
 
 
-def add_additional_span_data(hub, span):
-    # type: (sentry_sdk.Hub, sentry_sdk.tracing.Span) -> None
-    """
-    Adds additional data to the span
-    """
-    if span.op == OP.DB:
-        add_query_source(hub, span)
-
-
 def extract_sentrytrace_data(header):
     # type: (Optional[str]) -> Optional[Dict[str, Union[str, bool, None]]]
     """
